summaryrefslogtreecommitdiff
path: root/libavcodec/h264.h
diff options
context:
space:
mode:
authorClément Bœsch <u@pkh.me>2016-06-21 21:55:20 +0200
committerClément Bœsch <u@pkh.me>2016-06-21 21:55:34 +0200
commit8ef57a0d6154119e1a616dd8c29e8c32e35808a0 (patch)
tree26c51bc5d99260b44ba3a2585091ca764559f939 /libavcodec/h264.h
parent373b82066cd4d0c7f42af9b03e8cdc1085e1a6e5 (diff)
parent41ed7ab45fc693f7d7fc35664c0233f4c32d69bb (diff)
Merge commit '41ed7ab45fc693f7d7fc35664c0233f4c32d69bb'
* commit '41ed7ab45fc693f7d7fc35664c0233f4c32d69bb': cosmetics: Fix spelling mistakes Merged-by: Clément Bœsch <u@pkh.me>
Diffstat (limited to 'libavcodec/h264.h')
-rw-r--r--libavcodec/h264.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libavcodec/h264.h b/libavcodec/h264.h
index c4d29210aa..efe3555132 100644
--- a/libavcodec/h264.h
+++ b/libavcodec/h264.h
@@ -21,7 +21,7 @@
/**
* @file
- * H.264 / AVC / MPEG4 part10 codec.
+ * H.264 / AVC / MPEG-4 part10 codec.
* @author Michael Niedermayer <michaelni@gmx.at>
*/
@@ -433,7 +433,7 @@ typedef struct H264SliceContext {
DECLARE_ALIGNED(8, uint16_t, sub_mb_type)[4];
- ///< as a dct coefficient is int32_t in high depth, we need to reserve twice the space.
+ ///< as a DCT coefficient is int32_t in high depth, we need to reserve twice the space.
DECLARE_ALIGNED(16, int16_t, mb)[16 * 48 * 2];
DECLARE_ALIGNED(16, int16_t, mb_luma_dc)[3][16 * 2];
///< as mb is addressed by scantable[i] and scantable is uint8_t we can either
@@ -472,7 +472,7 @@ typedef struct H264Context {
H2645Packet pkt;
- int pixel_shift; ///< 0 for 8-bit H264, 1 for high-bit-depth H264
+ int pixel_shift; ///< 0 for 8-bit H.264, 1 for high-bit-depth H.264
/* coded dimensions -- 16 * mb w/h */
int width, height;
@@ -563,7 +563,7 @@ typedef struct H264Context {
int nal_unit_type;
/**
* Used to parse AVC variant of h264
*/
int is_avc; ///< this flag is != 0 if codec is avc1
int nal_length_size; ///< Number of bytes used for nal length (1, 2 or 4)
@@ -563,7 +563,7 @@ typedef struct H264Context {
int nal_unit_type;
/**
- * Used to parse AVC variant of h264
+ * Used to parse AVC variant of H.264
*/
int is_avc; ///< this flag is != 0 if codec is avc1